import { enumDictList, queryLabelList, queryCategoryList, queryAuthList } from "@/services/global"
import { useReducer, useState } from "react"

type State = {
    enumList?: { [key: string]: any[] },//枚举
    labelList?: any[],//标签列表
    categoryList?: any[],//分类列表
    authList?: any[],//作者列表
}
type Action = {
    params?: any,
    type: 'setEnum' | 'setLabelList' | 'setCategoryList' | 'setAuthList' | "setAll",
}
export function reducer(state: State, action: Action) {
    let { type, params } = action
    switch (type) {
        case 'setEnum':
            return { ...state, enumList: params?.enumList }
        case 'setLabelList':
            return { ...state, labelList: params?.labelList }
        case 'setCategoryList':
            return { ...state, categoryList: params?.categoryList }
        case 'setAuthList':
            return { ...state, authList: params?.authList }
        case 'setAll':
            return { ...state, ...params }
        default:
            return state;
    }
}
export default (): { state: State, init: () => void } => {
    const [state, dispatch] = useReducer(reducer, {})
    let isLoding = false
    const init = async () => {
        if (isLoding) {
            return
        }
        console.log("初始化")
        isLoding = true
        let enumData: any = await enumDictList().then((res) => res.data).catch((err) => { console.log(err) })
        let labelList = await queryLabelList().then((res) => res.data).catch((err) => { console.log(err) })
        let categoryList = await queryCategoryList().then((res) => res.data).catch((err) => { console.log(err) })
        let authList = await queryAuthList().then((res) => res.data).catch((err) => { console.log(err) })
        let enumList: { [key: string]: any[] } = {}
        if (enumData) {
            Object.values(enumData.enums).map((item: any) => {
                enumList[item.name] = item
            })
        }
        dispatch({ type: "setAll", params: { enumList, labelList, categoryList, authList } })
        isLoding = false
    }
    return {
        state,
        init
    }
}