import { PageContainer, ProTable } from "@ant-design/pro-components"
import { columns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { useModel } from "@umijs/max"
import { shortBookInfoList, shortBookInfoParagraphList } from "@/services/miniApp/bookManage"
import { useState } from "react"
import { Drawer } from "antd"
import ReadText from "../components/readText"
const wordCountRanges: any = {
    "": { start: null, end: null }, // 全部
    "0-2": { start: 0, end: 2 * 10000 },
    "2-5": { start: 2 * 10000, end: 5 * 10000 },
    "5-10": { start: 5 * 10000, end: 10 * 10000 },
    "10-20": { start: 10 * 10000, end: 20 * 10000 },
    "20-40": { start: 20 * 10000, end: 40 * 10000 },
    "40-100": { start: 40 * 10000, end: 100 * 10000 },
    "100-150": { start: 100 * 10000, end: 150 * 10000 },
    "150-200": { start: 150 * 10000, end: 200 * 10000 },
    "200-300": { start: 200 * 10000, end: 300 * 10000 },
    "300-0": { start: 300 * 10000, end: null }, // 300万以上
};
const Page: React.FC = () => {
    let { initialState } = useModel("@@initialState")
    let { state } = useModel('global')
    const [openBook, setOpneBook] = useState<any>(null)//阅读小说
    let getList = useAjax((params) => shortBookInfoList(params), { type: 'table' })
    let getParagraphList = useAjax((params) => shortBookInfoParagraphList(params))


    // 看小说
    const lookBook = (params: any) => {
        let { id, pageNum, pageSize } = params
        return getParagraphList.run({ id, pageNum, pageSize, backContent: 1 }).then(res => {
            setOpneBook({ ...res.data, ...params })
            return res.data
        })
    }
    return <PageContainer title={false}
        tabProps={{ type: 'card' }}
    >
        <ProTable<any, any>
            params={{
                miniappId: initialState?.selectApp?.id || "",
                distributorId: initialState?.currentUser?.distributorId,
                appType: initialState?.selectApp?.appType || ""
            }}
            headerTitle={"短篇小说列表"}
            rowKey={(r) => r.bookId}
            search={{
                labelWidth: 90,
                searchGutter: [10, 15],
            }}
            // ghost={true}//去除表格的背景一些配置改变ui
            beforeSearchSubmit={(params) => {//处理搜索数据
                let newParams = Object.entries(params).reduce((acc: any, [key, value]) => {
                    // 过滤掉空值，包括空字符串和 null
                    if (value !== '' && value != null) {
                        acc[key] = value;
                    }
                    if (key === 'wordCount' && value) {
                        let obj = wordCountRanges[value]
                        acc['startWordCount'] = obj.start
                        acc['endWordCount'] = obj.end
                        delete acc[key]
                    }
                    return acc;
                }, {});
                return newParams
            }}
            request={async (params) => {
                return await getList.run(params)
            }}
            columns={columns({ authList: state?.authList, enumList: state?.enumList,lookBook })}
        // bordered
        />
        {/* 阅读小说 */}
        <Drawer
            open={!!openBook}
            placement="right"
            onClose={() => { setOpneBook(null) }}
            footer={null}
            width={'65%'}
            destroyOnClose={true}
            // getContainer={false}
            bodyStyle={{ padding: 0 }}
            closeIcon={false}
            title={<div style={{ fontSize: 20}}>{openBook?.bookName ? openBook?.bookName : ""}</div>}
        >
            <ReadText data={openBook} next={lookBook} />
        </Drawer>
    </PageContainer>

}
export default Page