import { api } from '@/services/api';
import { request } from '@umijs/max';
type Page = {
  pageSize: number | string,
  pageNum: number | string
}
interface BookId {
  bookId: string,
}
interface LongBookParams extends Page, BookId { };
interface PublicParams {
  miniappId: string,//微信小程序组件ID
  distributorId: string,//分销商ID
  appType: string,//小程序类型 1:微信小程序、2：抖音小程序
}
interface CombinedParams extends BookId, PublicParams { };

export interface Params extends Page, PublicParams {
  workDirection?: string,//作品方向;0-男频 1-女频
  categoryId?: string,//类别ID
  source?: string,//来源
  labelIds?: string,//标签ID
  bookName?: string,//小说名
  authorId?: string,//作者
  startWordCount?: string,//开始字数
  endWordCount?: string,//结束字数
  bookStatus?: string,//书籍状态;0-连载中 1-已完结
  shelveStatus?: string,//上下架状态;0-上架 1-下架
  paymentType?: string,//付费类型：0-免费 1-按千字收费 2-整本收费
  vipFree?: string,//vip 是否免费阅读;false-否，true-是
}
interface ConfigParmas {
  id?:number,//配置ID
  vipFree:boolean,//vip免费阅读
  paymentType:any[],//小说付费方式（0：免费、1：按千字收费、2：整本收费、3：按段落收费
  paymentCoin:number,//收费书币
  remark:string,//配置
}
interface LongConfigParmas extends PublicParams,BookId,ConfigParmas{
  beginPayChapterNo:number,//付费章节
}
// ======================================长篇================================
/**小说分页列表 */
export async function longBookInfoList(params: Params) {
  return request(api + '/admin/longBookInfo/list', {
    method: 'GET',
    params
  });
}
/**小说付费配置详情 */
export async function longBookInfoConfig(params: CombinedParams) {
  return request(api + '/admin/longBookInfo/configDetail', {
    method: 'GET',
    params
  });
}
/**小说章节列表 */
export async function longBookInfoChapterList(params: LongBookParams) {
  return request(api + '/admin/longBookInfo/chapterList', {
    method: 'GET',
    params
  });
}
/**小说章节全部列表 */
export async function longBookInfoChapterAllList(bookId: number) {
  return request(api + `/admin/longBookInfo/chapterAllList/${bookId}`, {
    method: 'GET',
  });
}
/**小说付费章节内容 */
export async function longBookInfoChapterContent(chapterId: number) {
  return request(api + `/admin/longBookInfo/chapterContent/${chapterId}`, {
    method: 'GET',
  });
}
/**小说付费配置 */
export async function longBookInfoBookConfig(data: LongConfigParmas) {
  return request(api + `/admin/longBookInfo/bookConfig`, {
    method: 'POST',
    data
  });
}

interface ShortConfigParmas extends PublicParams,BookId,ConfigParmas{
  beginPayParagraphNo:number,//付费段落
  paymentAmount:number,//收费金额
}
interface ShortBookParams extends Page, BookId { 
  backContent?:boolean,//是否返回段落的内容

};
// ======================================短篇================================
/**小说列表 */
export async function shortBookInfoList(params: Params) {
  return request(api + '/admin/shortBookInfo/list', {
    method: 'GET',
    params
  })
}
/**小说付费配置详情 */
export async function shortBookInfoConfig(params: CombinedParams) {
  return request(api + '/admin/shortBookInfo/configDetail', {
    method: 'GET',
    params
  });
}
/**小说段落列表 */
export async function shortBookInfoParagraphList(params: ShortBookParams) {
  return request(api + '/admin/shortBookInfo/paragraphList', {
    method: 'GET',
    params
  });
}
/**小说段落全部列表 */
export async function shortBookInfoParagraphAllList(bookId: number) {
  return request(api + `/admin/shortBookInfo/paragraphAllList/${bookId}`, {
    method: 'GET',
  });
}
/**小说付费配置 */
export async function shortBookInfoBookConfig(data: ShortConfigParmas) {
  return request(api + `/admin/shortBookInfo/bookConfig`, {
    method: 'POST',
    data
  });
}